pub fn fingerprint_file(path: &Path) -> Option<Fingerprint>Expand description
The Fingerprint of the regular file at path, or None when there is
no readable regular file there. Directories, devices, and pipes are never
opened.
pub fn fingerprint_file(path: &Path) -> Option<Fingerprint>The Fingerprint of the regular file at path, or None when there is
no readable regular file there. Directories, devices, and pipes are never
opened.